@@ -66,8 +66,8 @@ struct _GeditOpenDocumentSelector
 	GList *current_docs_items;
 	GList *all_items;
 
-	gint populate_liststore_is_idle : 1;
-	gint populate_scheduled : 1;
+	guint populate_liststore_is_idle : 1;
+	guint populate_scheduled : 1;
 };
 
 typedef enum
@@ -84,20 +84,22 @@ enum
 	N_COLUMNS
 };
 
-/* Signals */
+enum
+{
+	PROP_0,
+	PROP_WINDOW,
+	LAST_PROP
+};
+
+static GParamSpec *properties[LAST_PROP];
+
 enum
 {
 	SELECTOR_FILE_ACTIVATED,
 	LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL] = { 0 };
-
-enum
-{
-	PROP_0,
-	PROP_WINDOW
-};
+static guint signals[LAST_SIGNAL];
 
 /* Value 0xFF is reserved to mark the end of the array */
 #define BYTE_ARRAY_END 0xFF
@@ -301,7 +303,7 @@ create_row (GeditOpenDocumentSelector *selector,
 static gint
 sort_items_by_mru (FileItem *a,
                    FileItem *b,
-                   gpointer  unused)
+                   gpointer  unused G_GNUC_UNUSED)
 {
 	glong diff;
 
@@ -499,7 +501,7 @@ real_populate_liststore (gpointer data)
 	gtk_list_store_clear (selector->liststore);
 
 	selector_store = selector->selector_store;
-	filter = gedit_open_document_selector_store_get_recent_filter (selector_store);
+	filter = gedit_open_document_selector_store_get_filter (selector_store);
 	if (filter && *filter != '\0')
 	{
 		DEBUG_SELECTOR (g_print ("Selector(%p): populate liststore: all lists\n", selector););
@@ -559,14 +561,14 @@ real_populate_liststore (gpointer data)
 	                          selector, DEBUG_SELECTOR_TIMER_GET););
 	DEBUG_SELECTOR_TIMER_DESTROY
 
-	if (selector->populate_scheduled == TRUE)
+	if (selector->populate_scheduled)
 	{
 		selector->populate_scheduled = FALSE;
-		return TRUE;
+		return G_SOURCE_CONTINUE;
 	}
 	else
 	{
-		return FALSE;
+		return G_SOURCE_REMOVE;
 	}
 }
 
@@ -630,8 +632,8 @@ on_entry_changed (GtkEntry                  *entry,
 	const gchar *entry_text;
 
 	entry_text = gtk_entry_get_text (entry);
-	gedit_open_document_selector_store_set_recent_filter (selector->selector_store,
-	                                                      entry_text);
+	gedit_open_document_selector_store_set_filter (selector->selector_store,
+	                                               entry_text);
 
 	if (gtk_widget_get_mapped ( GTK_WIDGET (selector)))
 	{
@@ -753,7 +755,7 @@ gedit_open_document_selector_dispose (GObject *object)
 static void
 on_row_activated (GtkTreeView               *treeview,
                   GtkTreePath               *path,
-                  GtkTreeViewColumn         *column,
+                  GtkTreeViewColumn         *column G_GNUC_UNUSED,
                   GeditOpenDocumentSelector *selector)
 {
 	GtkTreeSelection *selection;
@@ -776,7 +778,7 @@ on_row_activated (GtkTreeView               *treeview,
 static void
 update_list_cb (GeditOpenDocumentSelectorStore *selector_store,
                 GAsyncResult                   *res,
-                gpointer                        user_data)
+                gpointer                        user_data G_GNUC_UNUSED)
 {
 	GList *list;
 	GError *error;
@@ -877,13 +879,13 @@ gedit_open_document_selector_mapped (GtkWidget *widget)
 }
 
 static GtkSizeRequestMode
-gedit_open_document_selector_get_request_mode (GtkWidget *widget)
+gedit_open_document_selector_get_request_mode (GtkWidget *widget G_GNUC_UNUSED)
 {
 	return GTK_SIZE_REQUEST_CONSTANT_SIZE;
 }
 
 static void
-gedit_open_document_selector_get_preferred_width (GtkWidget *widget,
+gedit_open_document_selector_get_preferred_width (GtkWidget *widget G_GNUC_UNUSED,
                                                   gint      *minimum_width,
                                                   gint      *natural_width)
 {
@@ -931,8 +933,8 @@ gedit_open_document_selector_get_property (GObject    *object,
 }
 
 static void
-gedit_open_document_selector_file_activated (GeditOpenDocumentSelector *selector,
-					     const gchar               *uri)
+gedit_open_document_selector_file_activated (GeditOpenDocumentSelector *selector G_GNUC_UNUSED,
+                                             const gchar               *uri      G_GNUC_UNUSED)
 {
 	/* Do nothing in the default handler */
 }
@@ -940,19 +942,28 @@ gedit_open_document_selector_file_activated (GeditOpenDocumentSelector *selector
 static void
 gedit_open_document_selector_class_init (GeditOpenDocumentSelectorClass *klass)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	gobject_class->constructed = gedit_open_document_selector_constructed;
-	gobject_class->dispose = gedit_open_document_selector_dispose;
+	object_class->constructed = gedit_open_document_selector_constructed;
+	object_class->dispose = gedit_open_document_selector_dispose;
 
-	gobject_class->get_property = gedit_open_document_selector_get_property;
-	gobject_class->set_property = gedit_open_document_selector_set_property;
+	object_class->get_property = gedit_open_document_selector_get_property;
+	object_class->set_property = gedit_open_document_selector_set_property;
 
 	widget_class->get_request_mode = gedit_open_document_selector_get_request_mode;
 	widget_class->get_preferred_width = gedit_open_document_selector_get_preferred_width;
 	widget_class->map = gedit_open_document_selector_mapped;
 
+	properties[PROP_WINDOW] =
+		g_param_spec_object ("window",
+		                     "Window",
+		                     "The GeditWindow this GeditOpenDocumentSelector is associated with",
+		                     GEDIT_TYPE_WINDOW,
+		                     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+
+	g_object_class_install_properties (object_class, LAST_PROP, properties);
+
 	signals[SELECTOR_FILE_ACTIVATED] =
 		g_signal_new_class_handler ("file-activated",
 		                            G_TYPE_FROM_CLASS (klass),
@@ -971,21 +982,11 @@ gedit_open_document_selector_class_init (GeditOpenDocumentSelectorClass *klass)
 	gtk_widget_class_bind_template_child (widget_class, GeditOpenDocumentSelector, placeholder_box);
 	gtk_widget_class_bind_template_child (widget_class, GeditOpenDocumentSelector, scrolled_window);
 	gtk_widget_class_bind_template_child (widget_class, GeditOpenDocumentSelector, search_entry);
-
-	g_object_class_install_property (gobject_class,
-	                                 PROP_WINDOW,
-	                                 g_param_spec_object ("window",
-	                                                      "Window",
-	                                                      "The GeditWindow this GeditOpenDocumentSelector is associated with",
-	                                                      GEDIT_TYPE_WINDOW,
-	                                                      G_PARAM_READWRITE |
-	                                                      G_PARAM_CONSTRUCT_ONLY |
-	                                                      G_PARAM_STATIC_STRINGS));
 }
 
 static void
-on_treeview_allocate (GtkWidget                 *widget,
-                      GdkRectangle              *allocation,
+on_treeview_allocate (GtkWidget                 *widget     G_GNUC_UNUSED,
+                      GdkRectangle              *allocation G_GNUC_UNUSED,
                       GeditOpenDocumentSelector *selector)
 {
 	GeditOpenDocumentSelectorStore *selector_store;
@@ -1065,10 +1066,10 @@ on_treeview_style_updated (GtkWidget                 *widget,
 }
 
 static void
-name_renderer_datafunc (GtkTreeViewColumn         *column,
-                        GtkCellRenderer           *name_renderer,
-                        GtkTreeModel              *liststore,
-                        GtkTreeIter               *iter,
+name_renderer_datafunc (GtkTreeViewColumn         *column        G_GNUC_UNUSED,
+                        GtkCellRenderer           *name_renderer G_GNUC_UNUSED,
+                        GtkTreeModel              *liststore     G_GNUC_UNUSED,
+                        GtkTreeIter               *iter          G_GNUC_UNUSED,
                         GeditOpenDocumentSelector *selector)
 {
 	g_object_set (selector->name_renderer, "foreground-rgba", &selector->name_label_color, NULL);
@@ -1076,10 +1077,10 @@ name_renderer_datafunc (GtkTreeViewColumn         *column,
 }
 
 static void
-path_renderer_datafunc (GtkTreeViewColumn         *column,
-                        GtkCellRenderer           *path_renderer,
-                        GtkTreeModel              *liststore,
-                        GtkTreeIter               *iter,
+path_renderer_datafunc (GtkTreeViewColumn         *column        G_GNUC_UNUSED,
+                        GtkCellRenderer           *path_renderer G_GNUC_UNUSED,
+                        GtkTreeModel              *liststore     G_GNUC_UNUSED,
+                        GtkTreeIter               *iter          G_GNUC_UNUSED,
                         GeditOpenDocumentSelector *selector)
 {
 	g_object_set (selector->path_renderer, "foreground-rgba", &selector->path_label_color, NULL);
