@@ -1,8 +1,10 @@
 /*
- * gedit-window.h
+ * gedit-recent.h
  * This file is part of gedit
  *
  * Copyright (C) 2005 - Paolo Maggi
+ * Copyright (C) 2014 - Paolo Borelli
+ * Copyright (C) 2014 - Jesse van den Kieboom
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,9 +28,26 @@
 
 G_BEGIN_DECLS
 
-void		 gedit_recent_add_document		(GeditDocument       *document);
+typedef struct
+{
+	GtkRecentManager *manager;
+	GtkRecentFilter *filter;
 
-void		 gedit_recent_remove_if_local		(GFile               *location);
+	gint limit;
+	gchar *substring_filter;
+
+	guint show_private : 1;
+	guint show_not_found : 1;
+	guint local_only : 1;
+} GeditRecentConfiguration;
+
+void		 gedit_recent_add_document		 (GeditDocument            *document);
+
+void		 gedit_recent_remove_if_local		 (GFile                    *location);
+
+void		 gedit_recent_configuration_init_default (GeditRecentConfiguration *config);
+void		 gedit_recent_configuration_destroy	 (GeditRecentConfiguration *config);
+GList		*gedit_recent_get_items			 (GeditRecentConfiguration *config);
 
 G_END_DECLS
 
